@@ -14,10 +14,9 @@ class ViewerCorona;
 class View : public PlasmaQuick::ContainmentView
 {
     Q_OBJECT
-    Q_PROPERTY(bool konsoleVisible READ konsoleVisible CONSTANT);
 
 public:
-    View(ViewerCorona *corona, bool konsoleVisible, QWindow *parent = nullptr);
+    View(ViewerCorona *corona, QWindow *parent = nullptr);
     ~View() override;
 
     void addApplet(const QString &applet);
@@ -25,7 +24,6 @@ public:
     void addFormFactor(const QString &formFactor = QStringLiteral("planar"));
     void addLocation(const QString &location = QStringLiteral("floating"));
     void emitExternalData(const QString &data);
-    bool konsoleVisible();
 
     Q_INVOKABLE void changeFormFactor(int formFactor);
     Q_INVOKABLE void changeLocation(int location);
@@ -39,7 +37,6 @@ protected:
 
 private:
     QString m_lastAppletName;
-    bool m_konsoleVisible;
 };
 
 #endif // VIEW_H
